README.md message placeholder

To build this project before publishing, run the following command
`python .\setup.py sdist bdist_wheel`

To publish this project, run the following command after building
`python -m twine upload --repository-url https://upload.pypi.org/legacy/ dist/*`

ref : https://www.codementor.io/@ajayagrawal295/how-to-publish-your-own-python-package-12tbhi20tf